%%
%% This is file `tuenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ltoutenc.dtx  (with options: `TU')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2026
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
%%% From File: ltoutenc.dtx
\ProvidesFile{tuenc.def}
 [2025/07/18 v2.1d
      Standard LaTeX file]
\providecommand\UnicodeEncodingName{TU}
\begingroup\expandafter\expandafter\expandafter\endgroup
\expandafter\ifx\csname XeTeXrevision\endcsname\relax
  \begingroup\expandafter\expandafter\expandafter\endgroup
  \expandafter\ifx\csname directlua\endcsname\relax
    \PackageWarningNoLine{fontenc}
      {\UnicodeEncodingName\space
       encoding is only available with XeTeX and LuaTeX.\MessageBreak
       Defaulting to T1 encoding}
      \def\encodingdefault{T1}
    \expandafter\expandafter\expandafter\endinput
  \else
    \def\UnicodeFontTeXLigatures{+tlig;}
    \ifnum\luatexversion<110
      \def\reserved@a#1{%
        \def\@remove@tlig##1{\@remove@tlig@##1\@nil#1\@nil\relax}
        \def\@remove@tlig@##1#1{\@remove@tlig@@##1}}
      \edef\reserved@b{\detokenize{+tlig;}}
      \expandafter\reserved@a\expandafter{\reserved@b}
      \def\@remove@tlig@@#1\@nil#2\relax{#1}
      \def\remove@tlig#1{%
        \begingroup
        \font\remove@tlig
        \expandafter\@remove@tlig\expandafter{\fontname\font}%
        \remove@tlig
        \char#1\relax
        \endgroup
      }
    \else
      \newprotectedluacmd\@remove@tlig@@@
      \now@and@everyjob{\directlua{
        local rawchar_func = token.create'@remove@tlig@@@'.index
        local forcehmode = tex.forcehmode
        local put_next = token.put_next
        local glyph_id = node.id'glyph'
        local rawchar_token = token.new(rawchar_func, token.command_id'lua_call')
        lua.get_functions_table()[rawchar_func] = function()
          local mode = tex.nest.top.mode
          if mode == 1 or mode == -1 then
            put_next(rawchar_token)
            return forcehmode(true)
          end
          local n = node.new(glyph_id, 256)
          n.font = font.current()
          n.char = token.scan_int()
          return node.write(n)
        end
      }}
      \def\remove@tlig#1{\@remove@tlig@@@#1\relax}
    \fi
  \fi
\else
  \def\UnicodeFontTeXLigatures{mapping=tex-text;}
  \def\remove@tlig#1{\XeTeXglyph\numexpr\XeTeXcharglyph#1\relax}
\fi
\def\UnicodeFontFile#1#2{"[#1]:#2"}
\def\UnicodeFontName#1#2{"#1:#2"}
\DeclareFontEncoding\UnicodeEncodingName{}{}
\def\add@unicode@accent#1#2{%
  \if\relax\detokenize{#2}\relax^^a0\else#2\fi
  \char#1\relax}
\def\DeclareUnicodeAccent#1#2{%
  \edef\reserved@a{#2}%
  \edef\reserved@b{\UnicodeEncodingName}%
  \ifx\reserved@a\reserved@b
    \def\reserved@a{\DeclareUnicodeAccent@{#1}}%
  \else
    \def\reserved@a{\DeclareUnicodeAccent@{#1}\UnicodeEncodingName}%
  \fi
  \reserved@a{#2}%
}
\def\DeclareUnicodeAccent@#1#2#3{%
  \DeclareTextCommand{#1}{#2}{\add@unicode@accent{#3}}%
}
{
\catcode\z@=11\relax
\gdef\DeclareUnicodeComposite#1#2#3{%
   \def\reserved@a##1##2{%
     \DeclareTextCompositeCommand#1\UnicodeEncodingName{#2}{%
   \iffontchar\font#3 ##2%
      \else ##1\fi}}%
    \expandafter\expandafter\expandafter\extract@default@composite
    \csname\UnicodeEncodingName\string#1\endcsname{#2}\@nil
   \bgroup
      \lccode\z@#3 %
      \lowercase{\egroup
      \expandafter\reserved@a\expandafter{\reserved@b}{^^@}}}%
}
\def\extract@default@composite#1{%
 \ifx\@text@composite#1%
   \expandafter\extract@default@composite@a
 \else
   \expandafter\extract@default@composite@b\expandafter#1%
 \fi}
\def\extract@default@composite@a#1\@text@composite#2\@nil{%
  \def\reserved@b{#2}}
\def\extract@default@composite@b#1#2\@nil{%
  \def\reserved@b{#1#2}}
\def\DeclareUnicodeSymbol#1{\DeclareTextSymbol{#1}{\UnicodeEncodingName}}
\def\DeclareUnicodeCommand#1{\DeclareTextCommand{#1}{\UnicodeEncodingName}}
\DeclareUnicodeCommand\textquotesingle {\remove@tlig{"0027}}
\DeclareUnicodeCommand\textasciigrave  {\remove@tlig{"0060}}
\DeclareUnicodeCommand\textquotedbl    {\remove@tlig{"0022}}
\DeclareUnicodeSymbol{\textdollar}          {"0024}
\DeclareUnicodeSymbol{\textless}            {"003C}
\DeclareUnicodeSymbol{\textgreater}         {"003E}
\DeclareUnicodeSymbol{\textbackslash}       {"005C}
\DeclareUnicodeSymbol{\textasciicircum}     {"005E}
\DeclareUnicodeSymbol{\textunderscore}      {"005F}
\DeclareUnicodeSymbol{\textbraceleft}       {"007B}
\DeclareUnicodeSymbol{\textbar}             {"007C}
\DeclareUnicodeSymbol{\textbraceright}      {"007D}
\DeclareUnicodeSymbol{\textasciitilde}      {"007E}
\DeclareUnicodeSymbol{\textexclamdown}      {"00A1}
\DeclareUnicodeSymbol{\textcent}            {"00A2}
\DeclareUnicodeSymbol{\textsterling}        {"00A3}
\DeclareUnicodeSymbol{\textcurrency}        {"00A4}
\DeclareUnicodeSymbol{\textyen}             {"00A5}
\DeclareUnicodeSymbol{\textbrokenbar}       {"00A6}
\DeclareUnicodeSymbol{\textsection}         {"00A7}
\DeclareUnicodeSymbol{\textasciidieresis}   {"00A8}
\DeclareUnicodeSymbol{\textcopyright}       {"00A9}
\DeclareUnicodeSymbol{\textordfeminine}     {"00AA}
\DeclareUnicodeSymbol{\guillemetleft}       {"00AB}
\DeclareUnicodeSymbol{\guillemotleft}       {"00AB}
\DeclareUnicodeSymbol{\textlnot}            {"00AC}
\DeclareUnicodeSymbol{\textregistered}      {"00AE}
\DeclareUnicodeSymbol{\textasciimacron}     {"00AF}
\DeclareUnicodeSymbol{\textdegree}          {"00B0}
\DeclareUnicodeSymbol{\textpm}              {"00B1}
\DeclareUnicodeSymbol{\texttwosuperior}     {"00B2}
\DeclareUnicodeSymbol{\textthreesuperior}   {"00B3}
\DeclareUnicodeSymbol{\textasciiacute}      {"00B4}
\DeclareUnicodeSymbol{\textmu}              {"00B5}
\DeclareUnicodeSymbol{\textparagraph}       {"00B6}
\DeclareUnicodeSymbol{\textperiodcentered}  {"00B7}
\DeclareUnicodeSymbol{\textonesuperior}     {"00B9}
\DeclareUnicodeSymbol{\textordmasculine}    {"00BA}
\DeclareUnicodeSymbol{\guillemetright}      {"00BB}
\DeclareUnicodeSymbol{\guillemotright}      {"00BB}
\DeclareUnicodeSymbol{\textonequarter}      {"00BC}
\DeclareUnicodeSymbol{\textonehalf}         {"00BD}
\DeclareUnicodeSymbol{\textthreequarters}   {"00BE}
\DeclareUnicodeSymbol{\textquestiondown}    {"00BF}
\DeclareUnicodeSymbol{\AE}                  {"00C6}
\DeclareUnicodeSymbol{\DH}                  {"00D0}
\DeclareUnicodeSymbol{\texttimes}           {"00D7}
\DeclareUnicodeSymbol{\O}                   {"00D8}
\DeclareUnicodeSymbol{\TH}                  {"00DE}
\DeclareUnicodeSymbol{\ss}                  {"00DF}
\DeclareUnicodeSymbol{\ae}                  {"00E6}
\DeclareUnicodeSymbol{\dh}                  {"00F0}
\DeclareUnicodeSymbol{\textdiv}             {"00F7}
\DeclareUnicodeSymbol{\o}                   {"00F8}
\DeclareUnicodeSymbol{\th}                  {"00FE}
\DeclareUnicodeSymbol{\DJ}                  {"0110}
\DeclareUnicodeSymbol{\dj}                  {"0111}
\DeclareUnicodeSymbol{\i}                   {"0131}
\DeclareUnicodeSymbol{\IJ}                  {"0132}
\DeclareUnicodeSymbol{\ij}                  {"0133}
\DeclareUnicodeSymbol{\L}                   {"0141}
\DeclareUnicodeSymbol{\l}                   {"0142}
\DeclareUnicodeSymbol{\NG}                  {"014A}
\DeclareUnicodeSymbol{\ng}                  {"014B}
\DeclareUnicodeSymbol{\OE}                  {"0152}
\DeclareUnicodeSymbol{\oe}                  {"0153}
\DeclareUnicodeSymbol{\textflorin}          {"0192}
\DeclareUnicodeSymbol{\j}                   {"0237}
\DeclareUnicodeSymbol{\textasciicaron}      {"02C7}
\DeclareUnicodeSymbol{\textasciibreve}      {"02D8}
\DeclareUnicodeSymbol{\textacutedbl}        {"02DD}
\DeclareUnicodeSymbol{\textgravedbl}        {"02F5}
\DeclareUnicodeSymbol{\texttildelow}        {"02F7}
\DeclareUnicodeSymbol{\textbaht}            {"0E3F}
\DeclareUnicodeSymbol{\SS}                  {"1E9E}
\DeclareUnicodeSymbol{\textcompwordmark}    {"200C}
\DeclareUnicodeSymbol{\textendash}          {"2013}
\DeclareUnicodeSymbol{\textemdash}          {"2014}
\DeclareUnicodeCommand{\textnonbreakinghyphen}
     {\iffontchar\font "2011 \char "2011 \else \mbox{-}\nobreak\hskip\z@ \fi}
\DeclareUnicodeCommand{\textfiguredash}
     {\iffontchar\font "2012 \char "2012 \else \char "2013 \fi}
\DeclareUnicodeCommand{\texthorizontalbar}
     {\iffontchar\font "2015 \char "2015 \else \char "2014 \fi}
\DeclareUnicodeSymbol{\textbardbl}          {"2016}
\DeclareUnicodeSymbol{\textquoteleft}       {"2018}
\DeclareUnicodeSymbol{\textquoteright}      {"2019}
\DeclareUnicodeSymbol{\quotesinglbase}      {"201A}
\DeclareUnicodeSymbol{\textquotedblleft}    {"201C}
\DeclareUnicodeSymbol{\textquotedblright}   {"201D}
\DeclareUnicodeSymbol{\quotedblbase}        {"201E}
\DeclareUnicodeSymbol{\textdagger}          {"2020}
\DeclareUnicodeSymbol{\textdaggerdbl}       {"2021}
\DeclareUnicodeSymbol{\textbullet}          {"2022}
\DeclareUnicodeSymbol{\textellipsis}        {"2026}
\DeclareUnicodeSymbol{\textperthousand}     {"2030}
\DeclareUnicodeSymbol{\textpertenthousand}  {"2031}
\DeclareUnicodeSymbol{\guilsinglleft}       {"2039}
\DeclareUnicodeSymbol{\guilsinglright}      {"203A}
\DeclareUnicodeSymbol{\textreferencemark}   {"203B}
\DeclareUnicodeSymbol{\textinterrobang}     {"203D}
\DeclareUnicodeSymbol{\textfractionsolidus} {"2044}
\DeclareUnicodeSymbol{\textlquill}          {"2045}
\DeclareUnicodeSymbol{\textrquill}          {"2046}
\DeclareUnicodeSymbol{\textdiscount}        {"2052}
\DeclareUnicodeSymbol{\textcolonmonetary}   {"20A1}
\DeclareUnicodeSymbol{\textlira}            {"20A4}
\DeclareUnicodeSymbol{\textnaira}           {"20A6}
\DeclareUnicodeSymbol{\textwon}             {"20A9}
\DeclareUnicodeSymbol{\textdong}            {"20AB}
\DeclareUnicodeSymbol{\texteuro}            {"20AC}
\DeclareUnicodeSymbol{\textpeso}            {"20B1}
\DeclareUnicodeSymbol{\textcelsius}         {"2103}
\DeclareUnicodeSymbol{\textnumero}          {"2116}
\DeclareUnicodeSymbol{\textcircledP}        {"2117}
\DeclareUnicodeSymbol{\textrecipe}          {"211E}
\DeclareUnicodeSymbol{\textservicemark}     {"2120}
\DeclareUnicodeSymbol{\texttrademark}       {"2122}
\DeclareUnicodeSymbol{\textohm}             {"2126}
\DeclareUnicodeSymbol{\textmho}             {"2127}
\DeclareUnicodeSymbol{\textestimated}       {"212E}
\DeclareUnicodeSymbol{\textleftarrow}       {"2190}
\DeclareUnicodeSymbol{\textuparrow}         {"2191}
\DeclareUnicodeSymbol{\textrightarrow}      {"2192}
\DeclareUnicodeSymbol{\textdownarrow}       {"2193}
\DeclareUnicodeSymbol{\textminus}           {"2212}

\DeclareUnicodeSymbol{\Hwithstroke}         {"0126}
\DeclareUnicodeSymbol{\hwithstroke}         {"0127}
\DeclareUnicodeCommand{\textasteriskcentered}{%
  \iffontchar\font"2217 \char"2217 \else
    \begingroup
      \fontsize
       {\the\dimexpr1.3\dimexpr\f@size pt\relax}%
       {\f@baselineskip}%
      \selectfont
      \raisebox{-0.7ex}[\dimexpr\height-0.7ex][0pt]{*}%
    \endgroup
  \fi
}
\DeclareUnicodeSymbol{\textsurd}            {"221A}
\DeclareUnicodeSymbol{\textlangle}          {"2329}
\DeclareUnicodeSymbol{\textrangle}          {"232A}
\DeclareUnicodeSymbol{\textblank}           {"2422}
\DeclareUnicodeSymbol{\textvisiblespace}    {"2423}
\DeclareUnicodeSymbol{\textopenbullet}      {"25E6}
\DeclareUnicodeSymbol{\textbigcircle}       {"25EF}
\DeclareUnicodeSymbol{\textmusicalnote}     {"266A}
\DeclareUnicodeSymbol{\textmarried}         {"26AD}
\DeclareUnicodeSymbol{\textdivorced}        {"26AE}
\DeclareUnicodeSymbol{\textinterrobangdown} {"2E18}
\DeclareUnicodeAccent{\`}{"0300}
\DeclareUnicodeAccent{\'}{"0301}
\DeclareUnicodeAccent{\^}{"0302}
\DeclareUnicodeAccent{\~}{"0303}
\DeclareUnicodeAccent{\=}{"0304}
\DeclareUnicodeAccent{\u}{"0306}
\DeclareUnicodeAccent{\.}{"0307}
\DeclareUnicodeAccent{\"}{"0308}
\DeclareUnicodeAccent{\r}{"030A}
\DeclareUnicodeAccent{\H}{"030B}
\DeclareUnicodeAccent{\v}{"030C}
\DeclareUnicodeAccent{\b}{"0332}
\DeclareUnicodeAccent{\d}{"0323}
\DeclareUnicodeAccent{\c}{"0327}
\DeclareUnicodeAccent{\k}{"0328}
\DeclareUnicodeCommand\textcommabelow[1]
  {\hmode@bgroup\ooalign{\null#1\crcr\hidewidth\raise-.31ex
   \hbox{\check@mathfonts\fontsize\ssf@size\z@
   \math@fontsfalse\selectfont,}\hidewidth}\egroup}
\DeclareUnicodeComposite{\^}              {}{"005E}
\DeclareUnicodeComposite{\~}              {}{"007E}
\DeclareUnicodeComposite{\`}             {A}{"00C0}
\DeclareUnicodeComposite{\'}             {A}{"00C1}
\DeclareUnicodeComposite{\^}             {A}{"00C2}
\DeclareUnicodeComposite{\~}             {A}{"00C3}
\DeclareUnicodeComposite{\"}             {A}{"00C4}
\DeclareUnicodeComposite{\r}             {A}{"00C5}
\DeclareUnicodeComposite{\c}             {C}{"00C7}
\DeclareUnicodeComposite{\`}             {E}{"00C8}
\DeclareUnicodeComposite{\'}             {E}{"00C9}
\DeclareUnicodeComposite{\^}             {E}{"00CA}
\DeclareUnicodeComposite{\"}             {E}{"00CB}
\DeclareUnicodeComposite{\`}             {I}{"00CC}
\DeclareUnicodeComposite{\'}             {I}{"00CD}
\DeclareUnicodeComposite{\^}             {I}{"00CE}
\DeclareUnicodeComposite{\"}             {I}{"00CF}
\DeclareUnicodeComposite{\~}             {N}{"00D1}
\DeclareUnicodeComposite{\`}             {O}{"00D2}
\DeclareUnicodeComposite{\'}             {O}{"00D3}
\DeclareUnicodeComposite{\^}             {O}{"00D4}
\DeclareUnicodeComposite{\~}             {O}{"00D5}
\DeclareUnicodeComposite{\"}             {O}{"00D6}
\DeclareUnicodeComposite{\`}             {U}{"00D9}
\DeclareUnicodeComposite{\'}             {U}{"00DA}
\DeclareUnicodeComposite{\^}             {U}{"00DB}
\DeclareUnicodeComposite{\"}             {U}{"00DC}
\DeclareUnicodeComposite{\'}             {Y}{"00DD}
\DeclareUnicodeComposite{\`}             {a}{"00E0}
\DeclareUnicodeComposite{\'}             {a}{"00E1}
\DeclareUnicodeComposite{\^}             {a}{"00E2}
\DeclareUnicodeComposite{\~}             {a}{"00E3}
\DeclareUnicodeComposite{\"}             {a}{"00E4}
\DeclareUnicodeComposite{\r}             {a}{"00E5}
\DeclareUnicodeComposite{\c}             {c}{"00E7}
\DeclareUnicodeComposite{\`}             {e}{"00E8}
\DeclareUnicodeComposite{\'}             {e}{"00E9}
\DeclareUnicodeComposite{\^}             {e}{"00EA}
\DeclareUnicodeComposite{\"}             {e}{"00EB}
\DeclareUnicodeComposite{\`}             \i {"00EC}
\DeclareUnicodeComposite{\`}             {i}{"00EC}
\DeclareUnicodeComposite{\'}             \i {"00ED}
\DeclareUnicodeComposite{\'}             {i}{"00ED}
\DeclareUnicodeComposite{\^}             \i {"00EE}
\DeclareUnicodeComposite{\^}             {i}{"00EE}
\DeclareUnicodeComposite{\"}             \i {"00EF}
\DeclareUnicodeComposite{\"}             {i}{"00EF}
\DeclareUnicodeComposite{\~}             {n}{"00F1}
\DeclareUnicodeComposite{\`}             {o}{"00F2}
\DeclareUnicodeComposite{\'}             {o}{"00F3}
\DeclareUnicodeComposite{\^}             {o}{"00F4}
\DeclareUnicodeComposite{\~}             {o}{"00F5}
\DeclareUnicodeComposite{\"}             {o}{"00F6}
\DeclareUnicodeComposite{\`}             {u}{"00F9}
\DeclareUnicodeComposite{\'}             {u}{"00FA}
\DeclareUnicodeComposite{\^}             {u}{"00FB}
\DeclareUnicodeComposite{\"}             {u}{"00FC}
\DeclareUnicodeComposite{\'}             {y}{"00FD}
\DeclareUnicodeComposite{\"}             {y}{"00FF}
\DeclareUnicodeComposite{\=}             {A}{"0100}
\DeclareUnicodeComposite{\=}             {a}{"0101}
\DeclareUnicodeComposite{\u}             {A}{"0102}
\DeclareUnicodeComposite{\u}             {a}{"0103}
\DeclareUnicodeComposite{\k}             {A}{"0104}
\DeclareUnicodeComposite{\k}             {a}{"0105}
\DeclareUnicodeComposite{\'}             {C}{"0106}
\DeclareUnicodeComposite{\'}             {c}{"0107}
\DeclareUnicodeComposite{\^}             {C}{"0108}
\DeclareUnicodeComposite{\^}             {c}{"0109}
\DeclareUnicodeComposite{\.}             {C}{"010A}
\DeclareUnicodeComposite{\.}             {c}{"010B}
\DeclareUnicodeComposite{\v}             {C}{"010C}
\DeclareUnicodeComposite{\v}             {c}{"010D}
\DeclareUnicodeComposite{\v}             {D}{"010E}
\DeclareUnicodeComposite{\v}             {d}{"010F}
\DeclareUnicodeComposite{\=}             {E}{"0112}
\DeclareUnicodeComposite{\=}             {e}{"0113}
\DeclareUnicodeComposite{\u}             {E}{"0114}
\DeclareUnicodeComposite{\u}             {e}{"0115}
\DeclareUnicodeComposite{\.}             {E}{"0116}
\DeclareUnicodeComposite{\.}             {e}{"0117}
\DeclareUnicodeComposite{\k}             {E}{"0118}
\DeclareUnicodeComposite{\k}             {e}{"0119}
\DeclareUnicodeComposite{\v}             {E}{"011A}
\DeclareUnicodeComposite{\v}             {e}{"011B}
\DeclareUnicodeComposite{\^}             {G}{"011C}
\DeclareUnicodeComposite{\^}             {g}{"011D}
\DeclareUnicodeComposite{\u}             {G}{"011E}
\DeclareUnicodeComposite{\u}             {g}{"011F}
\DeclareUnicodeComposite{\.}             {G}{"0120}
\DeclareUnicodeComposite{\.}             {g}{"0121}
\DeclareUnicodeComposite{\c}             {G}{"0122}
\DeclareUnicodeComposite{\c}             {g}{"0123}
\DeclareUnicodeComposite{\^}             {H}{"0124}
\DeclareUnicodeComposite{\^}             {h}{"0125}
\DeclareUnicodeComposite{\~}             {I}{"0128}
\DeclareUnicodeComposite{\~}             \i {"0129}
\DeclareUnicodeComposite{\~}             {i}{"0129}
\DeclareUnicodeComposite{\=}             {I}{"012A}
\DeclareUnicodeComposite{\=}             \i {"012B}
\DeclareUnicodeComposite{\=}             {i}{"012B}
\DeclareUnicodeComposite{\u}             {I}{"012C}
\DeclareUnicodeComposite{\u}             \i {"012D}
\DeclareUnicodeComposite{\u}             {i}{"012D}
\DeclareUnicodeComposite{\k}             {I}{"012E}
\DeclareUnicodeComposite{\k}             \i {"012F}
\DeclareUnicodeComposite{\k}             {i}{"012F}
\DeclareUnicodeComposite{\.}             {I}{"0130}
\DeclareUnicodeComposite{\^}             {J}{"0134}
\DeclareUnicodeComposite{\^}             \j {"0135}
\DeclareUnicodeComposite{\^}             {j}{"0135}
\DeclareUnicodeComposite{\c}             {K}{"0136}
\DeclareUnicodeComposite{\c}             {k}{"0137}
\DeclareUnicodeComposite{\'}             {L}{"0139}
\DeclareUnicodeComposite{\'}             {l}{"013A}
\DeclareUnicodeComposite{\c}             {L}{"013B}
\DeclareUnicodeComposite{\c}             {l}{"013C}
\DeclareUnicodeComposite{\v}             {L}{"013D}
\DeclareUnicodeComposite{\v}             {l}{"013E}
\DeclareUnicodeComposite{\'}             {N}{"0143}
\DeclareUnicodeComposite{\'}             {n}{"0144}
\DeclareUnicodeComposite{\c}             {N}{"0145}
\DeclareUnicodeComposite{\c}             {n}{"0146}
\DeclareUnicodeComposite{\v}             {N}{"0147}
\DeclareUnicodeComposite{\v}             {n}{"0148}
\DeclareUnicodeComposite{\=}             {O}{"014C}
\DeclareUnicodeComposite{\=}             {o}{"014D}
\DeclareUnicodeComposite{\u}             {O}{"014E}
\DeclareUnicodeComposite{\u}             {o}{"014F}
\DeclareUnicodeComposite{\H}             {O}{"0150}
\DeclareUnicodeComposite{\H}             {o}{"0151}
\DeclareUnicodeComposite{\'}             {R}{"0154}
\DeclareUnicodeComposite{\'}             {r}{"0155}
\DeclareUnicodeComposite{\c}             {R}{"0156}
\DeclareUnicodeComposite{\c}             {r}{"0157}
\DeclareUnicodeComposite{\v}             {R}{"0158}
\DeclareUnicodeComposite{\v}             {r}{"0159}
\DeclareUnicodeComposite{\'}             {S}{"015A}
\DeclareUnicodeComposite{\'}             {s}{"015B}
\DeclareUnicodeComposite{\^}             {S}{"015C}
\DeclareUnicodeComposite{\^}             {s}{"015D}
\DeclareUnicodeComposite{\c}             {S}{"015E}
\DeclareUnicodeComposite{\c}             {s}{"015F}
\DeclareUnicodeComposite{\v}             {S}{"0160}
\DeclareUnicodeComposite{\v}             {s}{"0161}
\DeclareUnicodeComposite{\c}             {T}{"0162}
\DeclareUnicodeComposite{\c}             {t}{"0163}
\DeclareUnicodeComposite{\v}             {T}{"0164}
\DeclareUnicodeComposite{\v}             {t}{"0165}
\DeclareUnicodeComposite{\~}             {U}{"0168}
\DeclareUnicodeComposite{\~}             {u}{"0169}
\DeclareUnicodeComposite{\=}             {U}{"016A}
\DeclareUnicodeComposite{\=}             {u}{"016B}
\DeclareUnicodeComposite{\u}             {U}{"016C}
\DeclareUnicodeComposite{\u}             {u}{"016D}
\DeclareUnicodeComposite{\r}             {U}{"016E}
\DeclareUnicodeComposite{\r}             {u}{"016F}
\DeclareUnicodeComposite{\H}             {U}{"0170}
\DeclareUnicodeComposite{\H}             {u}{"0171}
\DeclareUnicodeComposite{\k}             {U}{"0172}
\DeclareUnicodeComposite{\k}             {u}{"0173}
\DeclareUnicodeComposite{\^}             {W}{"0174}
\DeclareUnicodeComposite{\^}             {w}{"0175}
\DeclareUnicodeComposite{\^}             {Y}{"0176}
\DeclareUnicodeComposite{\^}             {y}{"0177}
\DeclareUnicodeComposite{\"}             {Y}{"0178}
\DeclareUnicodeComposite{\'}             {Z}{"0179}
\DeclareUnicodeComposite{\'}             {z}{"017A}
\DeclareUnicodeComposite{\.}             {Z}{"017B}
\DeclareUnicodeComposite{\.}             {z}{"017C}
\DeclareUnicodeComposite{\v}             {Z}{"017D}
\DeclareUnicodeComposite{\v}             {z}{"017E}
\DeclareUnicodeComposite{\v}             {A}{"01CD}
\DeclareUnicodeComposite{\v}             {a}{"01CE}
\DeclareUnicodeComposite{\v}             {I}{"01CF}
\DeclareUnicodeComposite{\v}             \i {"01D0}
\DeclareUnicodeComposite{\v}             {i}{"01D0}
\DeclareUnicodeComposite{\v}             {O}{"01D1}
\DeclareUnicodeComposite{\v}             {o}{"01D2}
\DeclareUnicodeComposite{\v}             {U}{"01D3}
\DeclareUnicodeComposite{\v}             {u}{"01D4}
\DeclareUnicodeComposite{\'}             \AE{"01FC}
\DeclareUnicodeComposite{\'}             {Æ}{"01FC}
\DeclareUnicodeComposite{\'}             \ae{"01FD}
\DeclareUnicodeComposite{\'}             {æ}{"01FD}
\DeclareUnicodeComposite{\=}             \AE{"01E2}
\DeclareUnicodeComposite{\=}             {Æ}{"01E2}
\DeclareUnicodeComposite{\=}             \ae{"01E3}
\DeclareUnicodeComposite{\=}             {æ}{"01E3}
\DeclareUnicodeComposite{\v}             {G}{"01E6}
\DeclareUnicodeComposite{\v}             {g}{"01E7}
\DeclareUnicodeComposite{\v}             {K}{"01E8}
\DeclareUnicodeComposite{\v}             {k}{"01E9}
\DeclareUnicodeComposite{\k}             {O}{"01EA}
\DeclareUnicodeComposite{\k}             {o}{"01EB}
\DeclareUnicodeComposite{\v}             \j {"01F0}
\DeclareUnicodeComposite{\v}             {j}{"01F0}
\DeclareUnicodeComposite{\'}             {G}{"01F4}
\DeclareUnicodeComposite{\'}             {g}{"01F5}
\DeclareUnicodeComposite{\textcommabelow}{S}{"0218}
\DeclareUnicodeComposite{\textcommabelow}{s}{"0219}
\DeclareUnicodeComposite{\textcommabelow}{T}{"021A}
\DeclareUnicodeComposite{\textcommabelow}{t}{"021B}
\DeclareUnicodeComposite{\=}             {Y}{"0232}
\DeclareUnicodeComposite{\=}             {y}{"0233}
\DeclareUnicodeComposite{\.}             {B}{"1E02}
\DeclareUnicodeComposite{\.}             {b}{"1E03}
\DeclareUnicodeComposite{\d}             {B}{"1E04}
\DeclareUnicodeComposite{\d}             {b}{"1E05}
\DeclareUnicodeComposite{\d}             {D}{"1E0C}
\DeclareUnicodeComposite{\d}             {d}{"1E0D}
\DeclareUnicodeComposite{\=}             {G}{"1E20}
\DeclareUnicodeComposite{\=}             {g}{"1E21}
\DeclareUnicodeComposite{\d}             {H}{"1E24}
\DeclareUnicodeComposite{\d}             {h}{"1E25}
\DeclareUnicodeComposite{\d}             {K}{"1E32}
\DeclareUnicodeComposite{\d}             {k}{"1E33}
\DeclareUnicodeComposite{\d}             {L}{"1E36}
\DeclareUnicodeComposite{\d}             {l}{"1E37}
\DeclareUnicodeComposite{\d}             {M}{"1E42}
\DeclareUnicodeComposite{\d}             {m}{"1E43}
\DeclareUnicodeComposite{\d}             {N}{"1E46}
\DeclareUnicodeComposite{\d}             {n}{"1E47}
\DeclareUnicodeComposite{\d}             {R}{"1E5A}
\DeclareUnicodeComposite{\d}             {r}{"1E5B}
\DeclareUnicodeComposite{\d}             {S}{"1E62}
\DeclareUnicodeComposite{\d}             {s}{"1E63}
\DeclareUnicodeComposite{\d}             {T}{"1E6C}
\DeclareUnicodeComposite{\d}             {t}{"1E6D}
\DeclareUnicodeComposite{\d}             {V}{"1E7E}
\DeclareUnicodeComposite{\d}             {v}{"1E7F}
\DeclareUnicodeComposite{\d}             {W}{"1E88}
\DeclareUnicodeComposite{\d}             {w}{"1E89}
\DeclareUnicodeComposite{\d}             {Z}{"1E92}
\DeclareUnicodeComposite{\d}             {z}{"1E93}
\DeclareUnicodeComposite{\d}             {A}{"1EA0}
\DeclareUnicodeComposite{\d}             {a}{"1EA1}
\DeclareUnicodeComposite{\d}             {E}{"1EB8}
\DeclareUnicodeComposite{\d}             {e}{"1EB9}
\DeclareUnicodeComposite{\d}             {I}{"1ECA}
\DeclareUnicodeComposite{\d}             {i}{"1ECB}
\DeclareUnicodeComposite{\d}             {O}{"1ECC}
\DeclareUnicodeComposite{\d}             {o}{"1ECD}
\DeclareUnicodeComposite{\d}             {U}{"1EE4}
\DeclareUnicodeComposite{\d}             {u}{"1EE5}
\DeclareUnicodeComposite{\d}             {Y}{"1EF4}
\DeclareUnicodeComposite{\d}             {y}{"1EF5}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\endinput
%%
%% End of file `tuenc.def'.
